==> gcc-11_11.2.0.orig.tar.gz: gcc-11.2.0/libstdc++-v3/testsuite/25_algorithms/equal/constexpr_neg.cc <==
// Copyright (C) 2020-2021 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

// { dg-options "-std=gnu++2a" }
// { dg-do compile { target c++2a xfail *-*-* } }
// { dg-require-normal-mode "" }

#include <algorithm>
#include <array>

constexpr bool
test01()
{
  constexpr std::array<int, 12> ca0{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11}};
  constexpr std::array<int, 12> ca1{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11}};

  const auto outa = std::equal(ca0.end(), ca0.begin(), ca1.begin());
  return outa;
}

static_assert(test01()); // { dg-error "outside the bounds" }

constexpr bool
test02()
{
  constexpr std::array<int, 12> ca0{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11}};
  constexpr std::array<int, 11> ca1{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}};

  const auto outa = std::equal(ca0.begin(), ca0.end(), ca1.begin());
  return outa;
}

static_assert(test02()); // { dg-error "outside the bounds" }

// { dg-prune-output "non-constant condition" }
// { dg-prune-output "in 'constexpr'" }

==> gcc-14_14.2.0.orig.tar.gz: gcc-14.2.0/libstdc++-v3/testsuite/25_algorithms/equal/constexpr_neg.cc <==
// Copyright (C) 2020-2024 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

// { dg-do compile { target c++20 } }
// { dg-require-normal-mode "" }

#include <algorithm>
#include <array>

constexpr bool
test01()
{
  constexpr std::array<int, 12> ca0{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11}};
  constexpr std::array<int, 12> ca1{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11}};

  const auto outa = std::equal(ca0.end(), ca0.begin(), ca1.begin());
  return outa;
}

static_assert(test01()); // { dg-error "non-constant condition" }

constexpr bool
test02()
{
  constexpr std::array<int, 12> ca0{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11}};
  constexpr std::array<int, 11> ca1{{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}};

  const auto outa = std::equal(ca0.begin(), ca0.end(), ca1.begin());
  return outa;
}

static_assert(test02()); // { dg-error "non-constant condition" }

// Errors occuring within <algorithm> internals:
// { dg-error "outside the bounds of array" "" { target *-*-* } 0 }
// { dg-prune-output "in 'constexpr'" }
